from setuptools import setup

classifiers = [
    "Programming Language :: Python :: 3",
    "License :: OSI Approved :: GNU General Public License v3 (GPLv3)"
]

with open("README.md", "r") as fh:
    long_description = fh.read()

setup( 
    name="helloworld-nhenseler",
    version="0.0.1",
    description="Say helllo!",
    py_modules=["helloworld-nhenseler"],
    package_dir={'': 'src'},
    long_description=long_description,
    long_description_content_type="text/markdown",
     #url='',
     author='Norbert Henseler',
     author_email='nhenseler@web.de',
)

    
    